Documentation
¶
Overview ¶
Package avro provides a user functionality to return the avro encoding of s.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrMissingNestedScema = errors.New("nested schema missing from parent")
ErrMissingNestedScema is returned when nested schemas are missing from the parent
var ErrUnsupportedFieldType = errors.New("Unsupported field type")
ErrUnsupportedFieldType is returned for unsupported field types.
Functions ¶
func ErrUnsupportedType ¶
ErrUnsupportedType is returned if the interface isn't a pointer to a struct
Types ¶
type Footballer ¶
Footballer represents the details of a footballer
type FootballerName ¶
type FootballerName struct {
Surname string `avro:"surname"`
Forename string `avro:"forename"`
AKA map[string]string `avro:"aka"`
}
FootballerName represents an object containing the footballers name
type NestedTestData ¶
type NestedTestData struct {
Team string `avro:"team"`
Footballer FootballerName `avro:"footballer"`
Stats int32 `avro:"stats"`
AKA map[string]string `avro:"aka"`
Silverware map[string]string `avro:"silverware"`
}
NestedTestData represents an object nested within an object
Click to show internal directories.
Click to hide internal directories.